@@ -20,7 +20,7 @@ sub await {
         sub { $result{'rejected'} = $_[0] },
     );
 
-    diag 'Starting await loop';
+    # diag 'Starting await loop';
 
     while (!keys %result) {
         Time::HiRes::sleep( _INTERVAL() );
@@ -28,7 +28,7 @@ sub await {
         $_->() for @$checks_ar;
     }
 
-    diag 'Ended await loop';
+    # diag 'Ended await loop';
 
     return $result{'resolved'} if exists $result{'resolved'};
 
